# readelf: -A
# This test is only valid on ELF based ports.
#not-target: *-*-*coff *-*-pe *-*-wince *-*-*aout* *-*-netbsd *-*-riscix*
Attribute Section: aeabi
File Attributes
  Tag_CPU_arch: v8
  Tag_CPU_arch_profile: Application
  Tag_THUMB_ISA_use: Thumb-2

